Welcome to Python Flickr API's documentation!
=============================================

`Flickr`_ is one of the most popular photo sharing websites. Their
public API makes it very easy to write applications that use Flickr
some way or another. The possibilities are limitless. This document
describes how to use the Flickr API in your Python programs using the
`Python Flickr API interface`_.

.. _`Flickr`: http://www.flickr.com/
.. _`Python Flickr API interface`: http://stuvel.eu/flickrapi


Contents:

.. toctree::
   :maxdepth: 2

   1-intro
   2-calling
   3-auth
   4-uploading
   5-unicode
   6-caching
   7-util
   8-shorturl
   9-links


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

